@@ -158,7 +158,7 @@ BROKER_HEARTBEAT = 60
 
 # OTEL TRACE
 OTEL_BK_DATA_TOKEN = os.getenv("OTEL_BK_DATA_TOKEN", "")
-OTEL_GRPC_HOST = os.getenv("OTEL_GRPC_ADDR", "")
+OTEL_GRPC_HOST = os.getenv("OTEL_GRPC_URL", "")
 OTEL_SAMPLER = os.getenv("OTEL_SAMPLER", "")
 
 # APP模块名称
